@@ -4,10 +4,6 @@ library(stringr)
 library(rvest)
 library(glue)
 
-expect_missing <- function(object) {
-  expect_true(is.na(object))
-}
-
 test_that("md_image creates a <img> tag (ex. 580)", {
   # https://github.github.com/gfm/#example-580
   lines <- md_image("/url", "foo", "title")
@@ -47,3 +43,19 @@ test_that("md_image creates a <img> tag without title (ex. 580)", {
     html_attr("alt") %>%
     expect_equal("foo")
 })
+
+test_that("md_image creates a <img> tag from named vector", {
+  lines <- md_image(foo = "/url")
+  lines %>%
+    md_convert() %>%
+    read_html() %>%
+    html_node("img") %>%
+    html_attr("src") %>%
+    expect_equal("/url")
+  lines %>%
+    md_convert() %>%
+    read_html() %>%
+    html_node("img") %>%
+    html_attr("alt") %>%
+    expect_equal("foo")
+})
